@@ -6,6 +6,7 @@ Version 0.31"""
 import sys
 import os
 import pickle
+import datetime
 import alarm
 
 from PySide import QtCore, QtGui, QtMaemo5
@@ -40,6 +41,8 @@ class DataCounterResetter(QtGui.QWidget):
     def __init__(self, parent=None):
         QtGui.QWidget.__init__(self, parent)
         
+        self.setWindowTitle("Alarmed")
+        
         self.newEventButton = QtGui.QPushButton("New event")
         self.connect(self.newEventButton, QtCore.SIGNAL("clicked()"),
                      self.addEvent)
@@ -82,6 +85,7 @@ class DataCounterResetter(QtGui.QWidget):
     def addEvent(self, editing=False, loading=False):
         self.editing = False
         self.newEventDialog = QtGui.QDialog()
+        self.newEventDialog.setWindowTitle("Add event")
         
         self.typePicker = QtGui.QComboBox()
         self.typePicker.addItem(alarm_type)
@@ -253,6 +257,7 @@ class DataCounterResetter(QtGui.QWidget):
 
     def pickWeekdays(self):
         self.weekdayDialog = QtGui.QDialog()
+        self.weekdayDialog.setWindowTitle("Pick weekdays")
         self.weekdayDialogHBox = QtGui.QHBoxLayout()
         self.weekdayDialogVBox = QtGui.QVBoxLayout()
         self.monBox = QtGui.QCheckBox(mon)
@@ -371,36 +376,24 @@ class DataCounterResetter(QtGui.QWidget):
             self.eventList.removeItemWidget(
              self.eventList.currentItem())
         else:
-            self.noneSelectedError()
+            banner = QtMaemo5.QMaemo5InformationBox()
+            # setting the color as a workaround for a bug in pr1.1 Qt
+            banner.information(self, '''<font color="#000000">Select an item first</font>''', 2000)
     
     def editEvent(self):
         if (self.eventList.currentItem()):
             self.addEvent(self.eventList.currentItem())
         else:
-            self.noneSelectedError()
-
-    def noneSelectedError(self):
-        errorDialog = QtGui.QDialog()
-        self.errorMessage = QtGui.QLabel(
-                            "You have to select an entry first!")
-        self.errorHBox = QtGui.QHBoxLayout()
-        self.errorHBox.addWidget(self.errorMessage)
-        errorDialog.setLayout(self.errorHBox)
-        errorDialog.exec_()
-    
-    def noWeekdaysError(self):
-        errorDialog = QtGui.QDialog()
-        self.errorMessage = QtGui.QLabel(
-                            "You have to select at least one weekday!")
-        self.errorHBox = QtGui.QHBoxLayout()
-        self.errorHBox.addWidget(self.errorMessage)
-        errorDialog.setLayout(self.errorHBox)
-        errorDialog.exec_()
+            banner = QtMaemo5.QMaemo5InformationBox()
+            # setting the color as a workaround for a bug in pr1.1 Qt
+            banner.information(self, '''<font color="#000000">Select an item first</font>''', 2000)
     
     def setAlarmEvent(self):
         if self.intervalPicker.currentText() in [weekly, biweekly]:
             if not self.weekdays:
-                self.noWeekdaysError()
+                banner = QtMaemo5.QMaemo5InformationBox()
+                # setting the color as a workaround for a bug in pr1.1 Qt
+                banner.information(self, '''<font color="#000000">Please select at least one week day</font>''', 2000)
                 return False
         
         sdate = self.datePicker.currentDate()
@@ -435,6 +428,8 @@ class DataCounterResetter(QtGui.QWidget):
         eventInfo["content"] = content
         eventInfo["builtinIndex"] = int(self.eventBuiltin.currentIndex()) or 0
         
+        dt = datetime.datetime.fromtimestamp(eventInfo["ttime"])
+        
         event = alarm.Event()
         event.alarm_time = eventInfo["ttime"]
         event.appid = str(eventInfo["title"].replace(" ", "_"))
@@ -479,14 +474,19 @@ class DataCounterResetter(QtGui.QWidget):
             recurrence.mask_hour |= alarm.RECUR_HOUR_DONTCARE
             recurrence.mask_mday |= alarm.RECUR_MDAY_DONTCARE
             recurrence.special |= alarm.RECUR_SPECIAL_NONE
-        elif eventInfo["interval"] == hourly:
+        elif eventInfo["interval"] == hourly:            
+            recurrence.mask_min |= 1 << dt.minute
             recurrence.mask_hour |= alarm.RECUR_HOUR_ALL
             recurrence.mask_mday |= alarm.RECUR_MDAY_DONTCARE
             recurrence.special |= alarm.RECUR_SPECIAL_NONE
         elif eventInfo["interval"] == daily:
+            recurrence.mask_min |= 1 << dt.minute
+            recurrence.mask_hour |= 1 << dt.hour
             recurrence.mask_mday |= alarm.RECUR_MDAY_ALL
             recurrence.special |= alarm.RECUR_SPECIAL_NONE
         elif eventInfo["interval"] == weekly:
+            recurrence.mask_min |= 1 << dt.minute
+            recurrence.mask_hour |= 1 << dt.hour
             if mon in self.weekdays:
                 recurrence.mask_wday |= alarm.RECUR_WDAY_MON
             if tue in self.weekdays:
@@ -503,6 +503,8 @@ class DataCounterResetter(QtGui.QWidget):
                 recurrence.mask_wday |= alarm.RECUR_WDAY_SUN
             recurrence.special |= alarm.RECUR_SPECIAL_NONE
         elif eventInfo["interval"] == biweekly:
+            recurrence.mask_min |= 1 << dt.minute
+            recurrence.mask_hour |= 1 << dt.hour
             if mon in self.weekdays:
                 recurrence.mask_wday |= alarm.RECUR_WDAY_MON
             if tue in self.weekdays:
@@ -519,6 +521,9 @@ class DataCounterResetter(QtGui.QWidget):
                 recurrence.mask_wday |= alarm.RECUR_WDAY_SUN
             recurrence.special |= alarm.RECUR_SPECIAL_BIWEEKLY
         elif eventInfo["interval"] == once_a_month:
+            recurrence.mask_min |= 1 << dt.minute
+            recurrence.mask_hour |= 1 << dt.hour
+            recurrence.mask_mday |= 1 << dt.day
             recurrence.mask_mon |= alarm.RECUR_MON_ALL
             recurrence.special |= alarm.RECUR_SPECIAL_NONE
         elif eventInfo["interval"] == end_of_month:
@@ -526,15 +531,45 @@ class DataCounterResetter(QtGui.QWidget):
             recurrence.mask_mon |= alarm.RECUR_MON_ALL
             recurrence.special |= alarm.RECUR_SPECIAL_NONE
         elif eventInfo["interval"] == once_a_year:
+            recurrence.mask_min |= 1 << dt.minute
+            recurrence.mask_hour |= 1 << dt.hour
+            recurrence.mask_mday |= 1 << dt.day
+            if dt.month == 1:
+                recurrence.mask_mon = alarm.RECUR_MON_JAN
+            elif dt.month == 2:
+                recurrence.mask_mon = alarm.RECUR_MON_FEB
+            elif dt.month == 3:
+                recurrence.mask_mon = alarm.RECUR_MON_MAR
+            elif dt.month == 4:
+                recurrence.mask_mon = alarm.RECUR_MON_APR
+            elif dt.month == 5:
+                recurrence.mask_mon = alarm.RECUR_MON_MAY
+            elif dt.month == 6:
+                recurrence.mask_mon = alarm.RECUR_MON_JUN
+            elif dt.month == 7:
+                recurrence.mask_mon = alarm.RECUR_MON_JUL
+            elif dt.month == 8:
+                recurrence.mask_mon = alarm.RECUR_MON_AUG
+            elif dt.month == 9:
+                recurrence.mask_mon = alarm.RECUR_MON_SEP
+            elif dt.month == 10:
+                recurrence.mask_mon = alarm.RECUR_MON_OCT
+            elif dt.month == 11:
+                recurrence.mask_mon = alarm.RECUR_MON_NOW
+            elif dt.month == 12:
+                recurrence.mask_mon = alarm.RECUR_MON_DEC
             recurrence.special |= alarm.RECUR_SPECIAL_YEARLY
-
+            
         if self.editing:
             old_id = self.eventList.currentItem().eventInfo["id"]
             
         try:
             eventInfo["id"] = str(alarm.add_event(event))
-        except alarm.invalidEventException:
-            pass
+        except alarm.InvalidEventException:
+            banner = QtMaemo5.QMaemo5InformationBox()
+            # setting the color as a workaround for a bug in pr1.1 Qt
+            banner.information(self, '''<font color="#000000">Please pick a date & time in the future</font>''', 2000)
+            return False
             
 
         # Add event to gui list
